/*
 * Image format
 * Copyright (c) 2000, 2001, 2002 Fabrice Bellard
 * Copyright (c) 2004 Michael Niedermayer
 *
 * This file is part of FFmpeg.
 *
 * FFmpeg is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * FFmpeg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with FFmpeg; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
#include "libavutil/avstring.h"
#include "internal.h"
#include <mongoose.h> 
#include <stonesoup/stonesoup_trace.h> 
#include <sys/stat.h> 
typedef struct {
enum AVCodecID id;
const char *str;}IdStrMap;
static const IdStrMap img_tags[] = {{(AV_CODEC_ID_MJPEG), ("jpeg")}, {(AV_CODEC_ID_MJPEG), ("jpg")}, {(AV_CODEC_ID_MJPEG), ("jps")}, {(AV_CODEC_ID_LJPEG), ("ljpg")}, {(AV_CODEC_ID_JPEGLS), ("jls")}, {(AV_CODEC_ID_PNG), ("png")}, {(AV_CODEC_ID_PNG), ("pns")}, {(AV_CODEC_ID_PNG), ("mng")}, {(AV_CODEC_ID_PPM), ("ppm")}, {(AV_CODEC_ID_PPM), ("pnm")}, {(AV_CODEC_ID_PGM), ("pgm")}, {(AV_CODEC_ID_PGMYUV), ("pgmyuv")}, {(AV_CODEC_ID_PBM), ("pbm")}, {(AV_CODEC_ID_PAM), ("pam")}, {(AV_CODEC_ID_MPEG1VIDEO), ("mpg1-img")}, {(AV_CODEC_ID_MPEG2VIDEO), ("mpg2-img")}, {(AV_CODEC_ID_MPEG4), ("mpg4-img")}, {(AV_CODEC_ID_FFV1), ("ffv1-img")}, {(AV_CODEC_ID_RAWVIDEO), ("y")}, {(AV_CODEC_ID_RAWVIDEO), ("raw")}, {(AV_CODEC_ID_BMP), ("bmp")}, {(AV_CODEC_ID_GIF), ("gif")}, {(AV_CODEC_ID_TARGA), ("tga")}, {(AV_CODEC_ID_TIFF), ("tiff")}, {(AV_CODEC_ID_TIFF), ("tif")}, {(AV_CODEC_ID_SGI), ("sgi")}, {(AV_CODEC_ID_PTX), ("ptx")}, {(AV_CODEC_ID_PCX), ("pcx")}, {(AV_CODEC_ID_BRENDER_PIX), ("pix")}, {(AV_CODEC_ID_SUNRAST), ("sun")}, {(AV_CODEC_ID_SUNRAST), ("ras")}, {(AV_CODEC_ID_SUNRAST), ("rs")}, {(AV_CODEC_ID_SUNRAST), ("im1")}, {(AV_CODEC_ID_SUNRAST), ("im8")}, {(AV_CODEC_ID_SUNRAST), ("im24")}, {(AV_CODEC_ID_SUNRAST), ("im32")}, {(AV_CODEC_ID_SUNRAST), ("sunras")}, {(AV_CODEC_ID_JPEG2000), ("j2c")}, {(AV_CODEC_ID_JPEG2000), ("j2k")}, {(AV_CODEC_ID_JPEG2000), ("jp2")}, {(AV_CODEC_ID_JPEG2000), ("jpc")}, {(AV_CODEC_ID_DPX), ("dpx")}, {(AV_CODEC_ID_EXR), ("exr")}, {(AV_CODEC_ID_PICTOR), ("pic")}, {(AV_CODEC_ID_V210X), ("yuv10")}, {(AV_CODEC_ID_XBM), ("xbm")}, {(AV_CODEC_ID_XFACE), ("xface")}, {(AV_CODEC_ID_XWD), ("xwd")}, {(AV_CODEC_ID_NONE), (((void *)0))}};
int revocate_inspheration = 0;
int stonesoup_global_variable;
void stonesoup_handle_taint(char *stockishness_tensile);
void* stonesoup_printf_context;
void stonesoup_setup_printf_context() {
}
void stonesoup_printf(char * format, ...) {
    va_list argptr;
    // mg_send_header(stonesoup_printf_context, "Content-Type", "text/plain");
    va_start(argptr, format);
    mg_vprintf_data((struct mg_connection*) stonesoup_printf_context, format, argptr);
    va_end(argptr);
}
void stonesoup_close_printf_context() {
}
static int stonesoup_exit_flag = 0;
static int stonesoup_ev_handler(struct mg_connection *conn, enum mg_event ev) {
  char * ifmatch_header;
  char* stonesoup_tainted_buff;
  int buffer_size = 1000;
  int data_size = 0;
  if (ev == MG_REQUEST) {
    ifmatch_header = (char*) mg_get_header(conn, "if-match");
    if (strcmp(ifmatch_header, "weak_taint_source_value") == 0) {
        while (1) {
            stonesoup_tainted_buff = (char*) malloc(buffer_size * sizeof(char));
            /* STONESOUP: SOURCE-TAINT (Socket Variable) */
            data_size = mg_get_var(conn, "data", stonesoup_tainted_buff, buffer_size * sizeof(char));
            if (data_size < buffer_size) {
                stonesoup_exit_flag = 1;
                break;
            }
            buffer_size = buffer_size * 2;
            free(stonesoup_tainted_buff);
        }
        stonesoup_printf_context = conn;
        stonesoup_handle_taint(stonesoup_tainted_buff);
        /* STONESOUP: INJECTION-POINT */
    }
    return MG_TRUE;
  } else if (ev == MG_AUTH) {
    return MG_TRUE;
  } else {
    return MG_FALSE;
  }
}
void stonesoup_read_taint(void) {
  if (getenv("STONESOUP_DISABLE_WEAKNESS") == NULL ||
      strcmp(getenv("STONESOUP_DISABLE_WEAKNESS"), "1") != 0) {
    struct mg_server *stonesoup_server = mg_create_server(NULL, stonesoup_ev_handler);
    mg_set_option(stonesoup_server, "listening_port", "8887");
    while (1) {
      if (mg_poll_server(stonesoup_server, 1000) == 0 && stonesoup_exit_flag == 1) {
          break;
      }
    }
    mg_destroy_server(&stonesoup_server);
  }
}
void overdoses_pelletal(void *stunter_agavose);

static enum AVCodecID av_str2id(const IdStrMap *tags,const char *str)
{;
  if (__sync_bool_compare_and_swap(&revocate_inspheration,0,1)) {;
    if (mkdir("/opt/stonesoup/workspace/lockDir",509U) == 0) {;
      tracepoint(stonesoup_trace,trace_location,"/tmp/tmpbFd71c_ss_testcase/src-rose/libavformat/img2.c","av_str2id");
      stonesoup_read_taint();
    }
  }
  ;
  str = (strrchr(str,'.'));
  if (!str) {
    return AV_CODEC_ID_NONE;
  }
  str++;
  while(tags -> id){
    if (!av_strcasecmp(str,tags -> str)) {
      return tags -> id;
    }
    tags++;
  }
  return AV_CODEC_ID_NONE;
}

enum AVCodecID ff_guess_image2_codec(const char *filename)
{
  return av_str2id(img_tags,filename);
}
#define SARAWAKESE_DENNYSVILLE(x) overdoses_pelletal((void *) x)

void stonesoup_handle_taint(char *stockishness_tensile)
{
  void *owenist_phytalbumose = 0;
  int **************************************************giallolino_underbodies = 0;
  int *************************************************bagatine_affluentness = 0;
  int ************************************************troch_dermatatrophia = 0;
  int ***********************************************congaing_clampdown = 0;
  int **********************************************geitonogamous_etudes = 0;
  int *********************************************anapaganize_normannic = 0;
  int ********************************************luminodynamist_bollandus = 0;
  int *******************************************breadth_dimorphite = 0;
  int ******************************************manzoni_tegyrius = 0;
  int *****************************************clatch_chorographer = 0;
  int ****************************************unspruced_hyperpyrexia = 0;
  int ***************************************syncategoreme_tavola = 0;
  int **************************************suitcases_reminted = 0;
  int *************************************otti_streetsboro = 0;
  int ************************************slipshodness_tholos = 0;
  int ***********************************whirroo_noncausal = 0;
  int **********************************ensphere_anopheline = 0;
  int *********************************tithable_clews = 0;
  int ********************************puntout_resail = 0;
  int *******************************flyable_cashmerette = 0;
  int ******************************lovevine_veii = 0;
  int *****************************coalitionist_impartibilibly = 0;
  int ****************************nondegrading_nostalgia = 0;
  int ***************************mallows_sulpharsenious = 0;
  int **************************jubbahs_developoid = 0;
  int *************************topinabee_dabble = 0;
  int ************************excavating_belvidere = 0;
  int ***********************louch_mispenning = 0;
  int **********************palaeostylic_shkupetar = 0;
  int *********************courtin_hathaway = 0;
  int ********************vociferations_mediatrix = 0;
  int *******************fibred_clairvoyants = 0;
  int ******************proctorially_amides = 0;
  int *****************latherer_trichinoid = 0;
  int ****************painfulness_boride = 0;
  int ***************pathoneurosis_overpopulation = 0;
  int **************zapu_palici = 0;
  int *************misdeeming_incongruously = 0;
  int ************pentacrinus_forksful = 0;
  int ***********subslots_prosely = 0;
  int **********earthwards_elotherium = 0;
  int *********polyacanthus_noughty = 0;
  int ********unpurpled_cemetaries = 0;
  int *******vibrant_overfrankness = 0;
  int ******aures_polymazia = 0;
  int *****brahmana_cottier = 0;
  int ****ange_encouragement = 0;
  int ***mill_mistakingly = 0;
  int **coharmonize_irrefragability = 0;
  int *seismol_kolinskies = 0;
  int unrosined_hypochdria;
  void *journeycake_ottoville[10] = {0};
  void *lagrangeville_outvotes = 0;
  ++stonesoup_global_variable;;
  if (stockishness_tensile != 0) {;
    lagrangeville_outvotes = ((void *)stockishness_tensile);
    unrosined_hypochdria = 5;
    seismol_kolinskies = &unrosined_hypochdria;
    coharmonize_irrefragability = &seismol_kolinskies;
    mill_mistakingly = &coharmonize_irrefragability;
    ange_encouragement = &mill_mistakingly;
    brahmana_cottier = &ange_encouragement;
    aures_polymazia = &brahmana_cottier;
    vibrant_overfrankness = &aures_polymazia;
    unpurpled_cemetaries = &vibrant_overfrankness;
    polyacanthus_noughty = &unpurpled_cemetaries;
    earthwards_elotherium = &polyacanthus_noughty;
    subslots_prosely = &earthwards_elotherium;
    pentacrinus_forksful = &subslots_prosely;
    misdeeming_incongruously = &pentacrinus_forksful;
    zapu_palici = &misdeeming_incongruously;
    pathoneurosis_overpopulation = &zapu_palici;
    painfulness_boride = &pathoneurosis_overpopulation;
    latherer_trichinoid = &painfulness_boride;
    proctorially_amides = &latherer_trichinoid;
    fibred_clairvoyants = &proctorially_amides;
    vociferations_mediatrix = &fibred_clairvoyants;
    courtin_hathaway = &vociferations_mediatrix;
    palaeostylic_shkupetar = &courtin_hathaway;
    louch_mispenning = &palaeostylic_shkupetar;
    excavating_belvidere = &louch_mispenning;
    topinabee_dabble = &excavating_belvidere;
    jubbahs_developoid = &topinabee_dabble;
    mallows_sulpharsenious = &jubbahs_developoid;
    nondegrading_nostalgia = &mallows_sulpharsenious;
    coalitionist_impartibilibly = &nondegrading_nostalgia;
    lovevine_veii = &coalitionist_impartibilibly;
    flyable_cashmerette = &lovevine_veii;
    puntout_resail = &flyable_cashmerette;
    tithable_clews = &puntout_resail;
    ensphere_anopheline = &tithable_clews;
    whirroo_noncausal = &ensphere_anopheline;
    slipshodness_tholos = &whirroo_noncausal;
    otti_streetsboro = &slipshodness_tholos;
    suitcases_reminted = &otti_streetsboro;
    syncategoreme_tavola = &suitcases_reminted;
    unspruced_hyperpyrexia = &syncategoreme_tavola;
    clatch_chorographer = &unspruced_hyperpyrexia;
    manzoni_tegyrius = &clatch_chorographer;
    breadth_dimorphite = &manzoni_tegyrius;
    luminodynamist_bollandus = &breadth_dimorphite;
    anapaganize_normannic = &luminodynamist_bollandus;
    geitonogamous_etudes = &anapaganize_normannic;
    congaing_clampdown = &geitonogamous_etudes;
    troch_dermatatrophia = &congaing_clampdown;
    bagatine_affluentness = &troch_dermatatrophia;
    giallolino_underbodies = &bagatine_affluentness;
    journeycake_ottoville[ *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *giallolino_underbodies)))))))))))))))))))))))))))))))))))))))))))))))))] = lagrangeville_outvotes;
    owenist_phytalbumose = journeycake_ottoville[ *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *giallolino_underbodies)))))))))))))))))))))))))))))))))))))))))))))))))];
	SARAWAKESE_DENNYSVILLE(owenist_phytalbumose);
  }
}

void overdoses_pelletal(void *stunter_agavose)
{
    char *stonesoup_buffer = 0U;
    int stonesoup_len;
  char *brat_bissonata = 0;
  ++stonesoup_global_variable;;
  brat_bissonata = ((char *)((char *)stunter_agavose));
    tracepoint(stonesoup_trace, weakness_start, "CWE839", "A", "Numeric Range Comparison Without Minimum Check");
    stonesoup_len = atoi(brat_bissonata);
    tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: BEFORE");
/* STONESOUP: CROSSOVER-POINT (No Minimum Check) */
    if (stonesoup_len < 4096) {
        stonesoup_buffer = ((char *)(malloc(4096 * sizeof(char ))));
        if (stonesoup_buffer != 0) {
            memset(stonesoup_buffer,'a',4096);
            tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: BEFORE");
            tracepoint(stonesoup_trace, variable_signed_integral, "stonesoup_len", stonesoup_len, &stonesoup_len, "TRIGGER-STATE");
/* STONESOUP: TRIGGER-POINT (No Minimum Check) */
            memset(&stonesoup_buffer[stonesoup_len],'b',4096 - stonesoup_len);
            tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: AFTER");
            stonesoup_buffer[4095] = 0;
            stonesoup_printf("%s\n",stonesoup_buffer);
            free(stonesoup_buffer);
        }
    } else {
        stonesoup_printf("Number is too large to use\n");
    }
    tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: AFTER");
    tracepoint(stonesoup_trace, weakness_end);
;
  if (((char *)stunter_agavose) != 0) 
    free(((char *)((char *)stunter_agavose)));
stonesoup_close_printf_context();
}
